import copy from 'clipboard-copy';
import { useCallback, useRef } from 'react';
import { useTimedToggle } from './useTimedToggle';
function isTextInput(node) {
    return !!node && (node.tagName === 'TEXTAREA' || node.tagName === 'INPUT');
}
function isClipboardSupported() {
    return !!(navigator.clipboard ||
        (document.execCommand &&
            document.queryCommandSupported &&
            document.queryCommandSupported('copy')));
}
function useClipboard(options) {
    if (options === void 0) { options = {}; }
    var targetRef = useRef(null);
    var _a = useTimedToggle(), copied = _a[0], toggleCopied = _a[1];
    function handleSuccess() {
        if (typeof options.onSuccess === 'function') {
            options.onSuccess();
        }
        if (options.copiedTimeout) {
            toggleCopied(options.copiedTimeout);
        }
        if (options.selectOnCopy && isTextInput(targetRef.current)) {
            targetRef.current.select();
        }
    }
    function handleError() {
        if (typeof options.onError === 'function') {
            options.onError();
        }
        var selectOnError = options.selectOnError !== false;
        if (selectOnError && isTextInput(targetRef.current)) {
            targetRef.current.select();
        }
    }
    function clipboardCopy(text) {
        copy(text)
            .then(handleSuccess)
            .catch(handleError);
    }
    var copyHandler = useCallback(function (text) {
        if (typeof text === 'string') {
            clipboardCopy(text);
        }
        else if (isTextInput(targetRef.current)) {
            clipboardCopy(targetRef.current.value);
        }
    }, []);
    return {
        copied: copied,
        copy: copyHandler,
        isSupported: isClipboardSupported,
        target: targetRef,
    };
}
export { useClipboard };
